Linux workstation

Fedora 44 native package

libffado-devel

Free firewire audio driver library development headers

Packages / Fedora 44 / Unspecified / libffado-devel

[Source: libffado]

Package: libffado-devel (2.4.9-10.fc44)

[Project overview: libffado]

External Resources:

Homepage: [www.ffado.org]

Similar packages:

  • [ffado]

    Free firewire audio driver library applications and utilities

  • [libffado]

    Free firewire audio driver library

Free firewire audio driver library development headers

Development files needed to build applications against libffado.

Other Packages Related to libffado-devel:

  • dep: /usr/bin/pkg-config

    Package not available

  • dep: libffado(aarch-64) (= 2.4.9-10.fc44)

    Package not available

  • dep: libffado.so.2()(64bit)

    Package not available

Download libffado-devel

ArchitecturePackage SizeInstalled SizeFiles
aarch64132 KiB563 KiB[list of files]
i686132 KiB563 KiB[list of files]
x86_64132 KiB563 KiB[list of files]

Rutas de archivos del paquete (41)

Paths come from the repository package-file index for the observed builds. They describe archive/package associations, not every file that will exist on a running system after maintainer scripts, alternatives, generated state, diversions, or installation choices.

  • /usr/include/libffado
  • /usr/include/libffado/ffado.h
  • /usr/lib64/libffado.so
  • /usr/lib64/pkgconfig/libffado.pc
  • /usr/lib/libffado.so
  • /usr/lib/pkgconfig/libffado.pc
  • /usr/share/doc/libffado-devel
  • /usr/share/doc/libffado-devel/html
  • /usr/share/doc/libffado-devel/html/annotated.html
  • /usr/share/doc/libffado-devel/html/classes.html
  • /usr/share/doc/libffado-devel/html/clipboard.js
  • /usr/share/doc/libffado-devel/html/dir_6e8c217afbb1bb0ba4979df1f37ad8c3.html
  • /usr/share/doc/libffado-devel/html/doxygen_crawl.html
  • /usr/share/doc/libffado-devel/html/doxygen.css
  • /usr/share/doc/libffado-devel/html/doxygen.svg
  • /usr/share/doc/libffado-devel/html/dynsections.js
  • /usr/share/doc/libffado-devel/html/ffado_8h.html
  • /usr/share/doc/libffado-devel/html/ffado_8h_source.html
  • /usr/share/doc/libffado-devel/html/files.html
  • /usr/share/doc/libffado-devel/html/functions.html
  • /usr/share/doc/libffado-devel/html/functions_vars.html
  • /usr/share/doc/libffado-devel/html/globals_defs.html
  • /usr/share/doc/libffado-devel/html/globals_enum.html
  • /usr/share/doc/libffado-devel/html/globals_eval.html
  • /usr/share/doc/libffado-devel/html/globals_func.html
  • /usr/share/doc/libffado-devel/html/globals.html
  • /usr/share/doc/libffado-devel/html/globals_type.html
  • /usr/share/doc/libffado-devel/html/graph_legend.html
  • /usr/share/doc/libffado-devel/html/graph_legend.md5
  • /usr/share/doc/libffado-devel/html/graph_legend.png
  • /usr/share/doc/libffado-devel/html/index.html
  • /usr/share/doc/libffado-devel/html/index.qhp
  • /usr/share/doc/libffado-devel/html/jquery.js
  • /usr/share/doc/libffado-devel/html/menudata.js
  • /usr/share/doc/libffado-devel/html/menu.js
  • /usr/share/doc/libffado-devel/html/navtree.css
  • /usr/share/doc/libffado-devel/html/structffado__device__info.html
  • /usr/share/doc/libffado-devel/html/structffado__device__info-members.html
  • /usr/share/doc/libffado-devel/html/structffado__options.html
  • /usr/share/doc/libffado-devel/html/structffado__options-members.html
  • /usr/share/doc/libffado-devel/html/tabs.css

Field source: Fedora 44 Everything aarch64 revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee

Usar este paquete

OpenFactory puede arrancar este sistema operativo en una máquina virtual del navegador, o iniciar una construcción que incluye el nombre nativo del paquete de este registro.

Versiones, suites y repositorios

Cada fila es metadato del índice de paquetes para una versión, arquitectura, suite y repositorio. Nombres, URL y tamaños vienen de la fuente; un enlace es un punto de descarga que puede cambiar, no una redistribución de OpenFactory.

VersionReleaseArchitectureRepositoryPackage sizeInstalled sizePublisher repository artifact
2.4.9-10.fc4444 / everythingaarch64Fedora 44 · Everything · aarch64132 KiB563 KiBPackages/l/libffado-devel-2.4.9-10.fc44.aarch64.rpm
2.4.9-10.fc4444 / everythingi686Fedora 44 · Everything · x86_64132 KiB563 KiBPackages/l/libffado-devel-2.4.9-10.fc44.i686.rpm
2.4.9-10.fc4444 / everythingx86_64Fedora 44 · Everything · x86_64132 KiB563 KiBPackages/l/libffado-devel-2.4.9-10.fc44.x86_64.rpm

Field source: Fedora 44 Everything aarch64 revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee

Sumas de comprobación y fechas de observación

For an APT source, signature verification authenticates the repository metadata chain and the Packages index containing this source-reported artifact digest. It does not certify package safety.

2.4.9-10.fc44 / aarch64Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: 2be9a7ce62f99ded9fa84bd6fe7fdcb0caae8835b52cd6556d657883c269b12a

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' '2be9a7ce62f99ded9fa84bd6fe7fdcb0caae8835b52cd6556d657883c269b12a' 'libffado-devel-2.4.9-10.fc44.aarch64.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 44 Everything aarch64 revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee

2.4.9-10.fc44 / i686Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: ebc58bcd9915e5bef021e9988ce0d4820028b0db8ad914a034893ecc3dbf08c1

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'ebc58bcd9915e5bef021e9988ce0d4820028b0db8ad914a034893ecc3dbf08c1' 'libffado-devel-2.4.9-10.fc44.i686.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 44 Everything x86_64 revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991

2.4.9-10.fc44 / x86_64Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: 874a47cf1d0cea95923bdb88e25d86253f514bec6a4c6e1064b13f955b789058

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' '874a47cf1d0cea95923bdb88e25d86253f514bec6a4c6e1064b13f955b789058' 'libffado-devel-2.4.9-10.fc44.x86_64.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 44 Everything x86_64 revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991

Completitud del registro

The completeness score measures metadata coverage, not software quality, security, compatibility, or suitability.

Summary and description
25/25
Artifact path and source digest
25/25
Dependency metadata
15/15
Package-file index
15/15
Homepage
5/5
License text
5/5
Source package or maintainer
10/10

Recorded total: 100/100

Field source: Fedora 44 Everything aarch64 revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee, Fedora 44 Everything x86_64 revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991. The cross-OS mapping is catalog-derived from the source-reported homepage; it does not establish authorship or publisher identity

Fuentes y procedencia

Field-source links above resolve here. Each source entry names the metadata publisher, trust tier, exact snapshot revision, signature result, and observation time; catalog-derived mappings are labeled separately.

  • Authoritative source; repository metadata signature verified, revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    236514c32119ab3c85b81fbb9e5e9d92b07aeba0d19d64c9b4fc9117a1863769
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-44-primary
    SHA-256 93642aec521a1e5e96dd715f7ae0ec0850ebc9de09a94ce03cae5263f26cc18a
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

  • Authoritative source; repository metadata signature verified, revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    1300b99ac5d04b5561ad901320c8bd59ed1553f4971c3ce2ca48c40242c66676
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-44-primary
    SHA-256 93642aec521a1e5e96dd715f7ae0ec0850ebc9de09a94ce03cae5263f26cc18a
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

libffado-devel Package for Fedora 44 | OpenFactory